@@ -73,7 +73,7 @@ def main(ctx, config, devtron_url, api_token, version):
             click.echo(f"tron version {__version__}")
         except:
             # Fallback to hardcoded version if import fails
-            click.echo("tron version 0.1.3")
+            click.echo("tron version 0.1.7")
         ctx.exit()
     
     ctx.ensure_object(dict)
@@ -128,14 +128,15 @@ def create_app(ctx, config, devtron_url, api_token):
 
 @main.command()
 @global_options
+@click.option('--allow-deletion', is_flag=True, help='Confirm deletion (required for actual deletion)')
 @click.pass_context
-def update_app(ctx, config, devtron_url, api_token):
+def update_app(ctx, config, devtron_url, api_token, allow_deletion):
     """Update an existing application in Devtron."""
     config_data, devtron_api = validate_and_initialize_api(ctx, config, devtron_url, api_token)
     ctx.obj['config_data'] = config_data
     ctx.obj['devtron_api'] = devtron_api
     
-    result = devtron_api.update_application(config_data)
+    result = devtron_api.update_application(config_data, allow_deletion)
     if result['success']:
         click.echo("Application updated successfully!")
     else:
