@@ -21,6 +21,8 @@ from .workflow.workflow_handler import Workflow
 # metadata save
 from .metadata.saveMetadata import DevtronAppMetadata
 
+from .env_override_configurations.overrideDeploymentTemplate import OverrideDeploymentTemplateHandler
+
 # Define what gets exposed when doing: from tron.core.app import ...
 __all__ = [
     "BaseConfiguration",
@@ -29,5 +31,6 @@ __all__ = [
     "GitHandler",
     "Workflow",
     "DevtronAppMetadata",
-    "UpdateGitHandler"
+    "UpdateGitHandler",
+    "OverrideDeploymentTemplateHandler"
 ]
