@@ -5,17 +5,18 @@ from jsonmerge import merge,Merger
 
 class DeploymentTemplateHandler:
     def __init__(self, base_url, headers):
-        self.base_url = base_url
-        self.headers = headers
-        self.devtron_utils = DevtronUtils(base_url, headers)
+        self.base_url                    = base_url
+        self.headers                     = headers
+        self.devtron_utils               = DevtronUtils(base_url, headers)
         self.base_configuration_approval = BaseConfigurationApproval(base_url, headers)
 
     def setup_base_deployment_template(self, app_id, config_data):
         bdt = config_data.get('base_configurations').get('deployment_template', {})
-        version = bdt.get('version')
-        chart_type = bdt.get('chart_type')
-        values_path = bdt.get('values_path')  # optional: path to custom values.yaml
+        version      = bdt.get('version')
+        chart_type   = bdt.get('chart_type')
+        values_path  = bdt.get('values_path')  # optional: path to custom values.yaml
         values_patch = bdt.get('values_patch')  # optional: dict to patch globalConfig
+
         if not version or not chart_type:
             return {'success': False, 'error': 'deployment_template.version and chart_type are required in config'}
         
@@ -169,6 +170,8 @@ class DeploymentTemplateHandler:
                 return {'success': False, 'error': f'API request failed: {response.text}'}
         except Exception as e:
             return {'success': False, 'error': f'Exception occurred: {str(e)}'}
+
+
     def get_basedeployment_template_chart_id(self, app_id, version, chart_type):
         """
         Fetch the chartRef id for a given app_id, version, and chart_type from Devtron.
@@ -193,6 +196,8 @@ class DeploymentTemplateHandler:
                 return {'success': False, 'error': f'API request failed: {response.text}'}
         except Exception as e:
             return {'success': False, 'error': f'Exception occurred: {str(e)}'}
+
+
     def _remove_newlines_from_strings(self, obj):
             """
             Recursively remove all \n from string values in a dict/list structure.
@@ -205,6 +210,8 @@ class DeploymentTemplateHandler:
                 return obj.replace('\n', '')
             else:
                 return obj
+
+
     def update_base_deployment_template(self, config_data,config_approval_in_base_deployment_template=None):
         app_id = self.devtron_utils.get_application_id_by_name(config_data.get('app_name')).get('app_id')
         chart_ref_id = self.get_latest_chart_ref_id(app_id)
@@ -214,50 +221,84 @@ class DeploymentTemplateHandler:
         existing_bdt_result = self.get_deployment_template_yaml(app_id, chart_ref_id)
         if not existing_bdt_result['success']:
             return {'success': False, 'error': f"Failed to get existing deployment template: {existing_bdt_result['error']}"}
-        else:
-            existing_bdt = existing_bdt_result['yaml'].get('globalConfig')
-            id=existing_bdt.get('id')
-            check_if_diff_in_base_deployment_template_version_result = self.check_if_diff_in_base_deployment_template_version(existing_bdt, config_data)
-            if check_if_diff_in_base_deployment_template_version_result['success']:
-                # print("There is a difference in base deployment template version.")
-                chartref_result = self.get_basedeployment_template_chart_id(app_id, config_data.get('base_configurations', {}).get('deployment_template', {}).get('version'), config_data.get('base_configurations', {}).get('deployment_template', {}).get('chart_type'))
-                if not chartref_result['success']:
-                    return {'success': False, 'error': f"Failed to get chartRef id: {chartref_result['error']}"}
-                chart_ref_id = chartref_result['id']
-                id=self.get_data_base_chart_ref_id(app_id, chart_ref_id)
 
-            values_patch=config_data.get('base_configurations', {}).get('deployment_template', {}).get('values_patch')
+        existing_bdt = existing_bdt_result['yaml'].get('globalConfig')
+        id=existing_bdt.get('id')
+        check_if_diff_in_base_deployment_template_version_result = self.check_if_diff_in_base_deployment_template_version(existing_bdt, config_data)
+        if check_if_diff_in_base_deployment_template_version_result['success']:
+            print("There is a difference in base deployment template version.")
+            chartref_result = self.get_basedeployment_template_chart_id(app_id, config_data.get('base_configurations', {}).get('deployment_template', {}).get('version'), config_data.get('base_configurations', {}).get('deployment_template', {}).get('chart_type'))
+            if not chartref_result['success']:
+                return {'success': False, 'error': f"Failed to get chartRef id: {chartref_result['error']}"}
+            chart_ref_id = chartref_result['id']
+            id=self.get_data_base_chart_ref_id(app_id, chart_ref_id)
+
+        values_path = config_data.get('base_configurations', {}).get('deployment_template', {}).get('values_path')
+        values_patch = config_data.get('base_configurations', {}).get('deployment_template', {}).get('values_patch')
+        values_override = None
+        
+        if values_path:
+            # Load custom values file as JSON/dict (no YAML conversion needed for API)
+            if not os.path.isfile(values_path):
+                return {'success': False, 'error': f"Custom values.yaml file not found: {values_path}"}
+            with open(values_path, 'r') as f:
+                values_override = yaml.safe_load(f)
+            values_override = self._remove_newlines_from_strings(values_override)
+        else:
             values_patch_json = json.loads(json.dumps(values_patch))
             values_override = merge(existing_bdt.get('defaultAppOverride'), values_patch_json)
-            show_application_metrics = config_data.get('base_configurations', {}).get('deployment_template', {}).get('show_application_metrics')
-            _diff = self.devtron_utils.compare_dicts(existing_bdt.get('defaultAppOverride'), values_override)
-            if not _diff["success"]:
-                return {"success": False, "error": f"Failed to check the diff between the deployment templates: {_diff['error']}"}
-            if_diff = _diff.get("is_differ", True)
-            if if_diff:
+        show_application_metrics = config_data.get('base_configurations', {}).get('deployment_template', {}).get('show_application_metrics')
+        _diff = self.devtron_utils.compare_dicts(existing_bdt.get('defaultAppOverride'), values_override)
+        if not _diff["success"]:
+            return {"success": False, "error": f"Failed to check the diff between the deployment templates: {_diff['error']}"}
+        if_diff = _diff.get("is_differ", True)
+        if if_diff:
 
-                save_base_deployment_template_result = self.save_base_deployment_template(app_id, chart_ref_id, values_override, values_override=values_override, is_express_edit=False, resource_name="BaseDeploymentTemplate", id=id,config_approval=config_data.get('config_approval', {}),config_approval_in_base_deployment_template=config_approval_in_base_deployment_template, show_application_metrics=show_application_metrics)
+            save_base_deployment_template_result = self.save_base_deployment_template(app_id, chart_ref_id, existing_bdt.get('defaultAppOverride'), values_override=values_override, is_express_edit=False, resource_name="BaseDeploymentTemplate", id=id,config_approval=config_data.get('config_approval', {}),config_approval_in_base_deployment_template=config_approval_in_base_deployment_template, show_application_metrics=show_application_metrics)
+            if not save_base_deployment_template_result['success']:
+                return {'success': False, 'error': f"Failed to save base deployment template: {save_base_deployment_template_result['error']}"}
+            else:
+                return {'success': True, 'message': 'Base deployment template updated successfully.'}
+        else:
+
+            if check_if_diff_in_base_deployment_template_version_result['success']:
+                save_base_deployment_template_result = self.save_base_deployment_template(app_id, chart_ref_id,
+                                                                                          existing_bdt.get('defaultAppOverride'),
+                                                                                          values_override=values_override,
+                                                                                          is_express_edit=False,
+                                                                                          resource_name="BaseDeploymentTemplate",
+                                                                                          id=id,
+                                                                                          config_approval=config_data.get(
+                                                                                              'config_approval',
+                                                                                              {}),
+                                                                                          config_approval_in_base_deployment_template=config_approval_in_base_deployment_template,
+                                                                                          show_application_metrics=show_application_metrics)
                 if not save_base_deployment_template_result['success']:
-                    return {'success': False, 'error': f"Failed to save base deployment template: {save_base_deployment_template_result['error']}"}
+                    return {'success': False,
+                            'error': f"Failed to save base deployment template: {save_base_deployment_template_result['error']}"}
                 else:
                     return {'success': True, 'message': 'Base deployment template updated successfully.'}
-            else:
-                if config_approval_in_base_deployment_template:
-                    draft = self.base_configuration_approval.get_base_deployment_template_drafts(app_id)
-                    if draft["success"]:
-                        if draft.get("data", {}):
-                            draft_id = draft.get("data", {}).get("draftId", 0)
-                            draft_version_id = draft.get("data", {}).get("draftVersionId", 0)
-                            draft_state = draft.get("data", {}).get("draftState", 0)
-                            if draft_state != 2:
-                                delete_draft = self.base_configuration_approval.delete_draft_base_deployment_template(draft_id, draft_version_id, 2)
-                                if not delete_draft["success"]:
-                                    return {'success': False, 'error': f"Failed to delete draft: {delete_draft['error']}"}
-                    else:
-                        return {'success': False, 'error': f"Failed to get draft: {draft['error']}"}
 
 
-                return {'success': True, 'message': 'Base deployment template is up to date.'}
+            if config_approval_in_base_deployment_template:
+                draft = self.base_configuration_approval.get_base_deployment_template_drafts(app_id)
+                if draft["success"]:
+                    if draft.get("data", {}).get("draftId", 0):
+                        draft_id = draft.get("data", {}).get("draftId", 0)
+                        draft_version_id = draft.get("data", {}).get("draftVersionId", 0)
+                        draft_state = draft.get("data", {}).get("draftState", 0)
+                        if draft_state != 2:
+                            delete_draft = self.base_configuration_approval.delete_draft_base_deployment_template(draft_id, draft_version_id, 2)
+                            if not delete_draft["success"]:
+                                return {'success': False, 'error': f"Failed to delete draft: {delete_draft['error']}"}
+                            print("No diff in deployment template hence discarding the draft...")
+                else:
+                    return {'success': False, 'error': f"Failed to get draft: {draft['error']}"}
+
+
+            return {'success': True, 'message': 'Base deployment template is up to date.'}
+
+
     def get_data_base_chart_ref_id(self, app_id, chart_ref_id):
         get_deployment_template_yaml_result = self.get_deployment_template_yaml(app_id, chart_ref_id)
         if get_deployment_template_yaml_result['success']:
@@ -265,15 +306,17 @@ class DeploymentTemplateHandler:
         else:
             print(f"Failed to get deployment template get data base chart ref id")
             return None
+
+
     def get_latest_chart_ref_id(self, app_id):
         latestAppChartRefResult = requests.get(f"{self.base_url}/orchestrator/chartref/autocomplete/{app_id}", headers=self.headers)
         if latestAppChartRefResult.status_code == 200:
             chart_ref_id = latestAppChartRefResult.json().get('result', {}).get('latestAppChartRef')
             return chart_ref_id
-        
         return None
+
+
     def check_if_diff_in_base_deployment_template_version(self,existing_bdt,config_data):
         if existing_bdt.get('refChartTemplateVersion') != config_data.get('base_configurations', {}).get('deployment_template', {}).get('version') :
-            # print("There is a difference in base deployment template version.")
             return {'success': True, 'message': 'Base deployment template version is different.'}
-        return {'success': False, 'message': 'Base deployment template version is the same.'}
\ No newline at end of file
+        return {'success': False, 'message': 'Base deployment template version is the same.'}
