@@ -115,7 +115,7 @@ class DevtronUtils:
             # Return primitive values as-is
             return obj
 
-    def _get_chart_name_from_id(self, app_id, chart_ref_id):
+    def _get_chart_details_from_id(self, app_id, chart_ref_id):
         """Get chart name from chart reference ID"""
         try:
             url = f"{self.base_url}/orchestrator/chartref/autocomplete/{app_id}"
@@ -125,7 +125,7 @@ class DevtronUtils:
                 chart_refs = result.get('chartRefs', [])
                 for chart_ref in chart_refs:
                     if chart_ref.get('id') == chart_ref_id:
-                        return chart_ref.get('name')
+                        return chart_ref
             return None
         except Exception as e:
             print(f"Warning: Could not fetch chart name: {str(e)}")
@@ -565,7 +565,7 @@ class DevtronUtils:
         """
         try:
             response = requests.get(
-                f'{self.base_url}/orchestrator/app/cd-pipeline/{app_id}/{cd_pipeline_id}',
+                f'{self.base_url}/orchestrator/app/v2/cd-pipeline/{app_id}/{cd_pipeline_id}',
                 headers=self.headers
             )
             
@@ -586,3 +586,50 @@ class DevtronUtils:
                 'error': f'Exception occurred: {str(e)}'
             }
 
+    @staticmethod
+    def get_plugin_details_by_id(base_url, headers, plugin_ids, app_id) -> dict:
+        try:
+            url = f"{base_url}/orchestrator/plugin/global/list/detail/v2"
+            payload = {
+                "appId": app_id,
+                "parentPluginIds": [],
+                "pluginIds": plugin_ids
+            }
+            response = requests.post(url, json=payload, headers=headers)
+            if response.status_code != 200:
+                return{
+                    'success': False,
+                    "error": "Not able to fetch the plugin details"
+
+                }
+            response = response.json()
+            result = response.get("result", {})
+            return {
+                "success": True,
+                "plugin_data": result
+            }
+
+        except Exception as e:
+            return {
+                'success': False,
+                "error": str(e)
+            }
+
+    @staticmethod
+    def get_plugin_details_by_name(base_url, headers, plugin_name: str) -> dict:
+        try:
+            new_plugin_name = plugin_name.replace(" ", "+")
+            api_url = f"{base_url.rstrip('/')}/orchestrator/plugin/global/list/v2?searchKey={new_plugin_name}&offset=0"
+            response = requests.get(api_url, headers=headers)
+            data = response.json()
+            status_code = data.get("code", 0)
+            if status_code == 200:
+                plugin_search_result = data.get("result", {})
+                if plugin_search_result:
+                    plugin_list = plugin_search_result.get("parentPlugins", [])
+                    for plugin in plugin_list:
+                        if plugin.get("name") == plugin_name:
+                            return {'success': True, 'plugin': plugin}
+            return {}
+        except Exception as e:
+            return {'success': False, 'error': f'Exception occurred: {str(e)}'}
\ No newline at end of file
